;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "tempel" "1.14"
  "Tempo templates/snippets with in-buffer field editing."
  '((emacs  "29.1")
    (compat "31"))
  :url "https://github.com/minad/tempel"
  :commit "c5fdc3806b486d9d86a54c50efac3d4a141e789d"
  :revdesc "1.14-0-gc5fdc3806b48"
  :keywords '("abbrev" "languages" "tools" "text")
  :authors '(("Daniel Mendler" . "mail@daniel-mendler.de"))
  :maintainers '(("Daniel Mendler" . "mail@daniel-mendler.de")))
